Hypergraph.CorrelationLength (Hypergraph v1.0.0)
View SourceCorrelation Length calculator using Mutual Information.
The Correlation Length measures how far structural information propagates in the hypergraph by calculating Mutual Information between distant regions.
Summary
Functions
Calculates Correlation Length for a hypergraph using Mutual Information decay.
Functions
@spec compute(Hypergraph.t(), pos_integer(), pos_integer(), pos_integer()) :: {:ok, float()} | {:error, :insufficient_data | :insufficient_points | :insufficient_positive_data | :no_decay | :singular_matrix}
Calculates Correlation Length for a hypergraph using Mutual Information decay.
Parameters
- hypergraph: Hypergraph
- max_distance: Maximum distance to consider
- region_size: Size of regions to compare
- samples: Number of random region pairs to sample
Returns
{:ok, correlation_length}|{:error, reason}